@@ -1,6 +1,6 @@
 docker_compose_device_schema = {
     "type": "object",
-    "additionalProperties": True,
+    "additionalProperties": False,
     "required": ["image"],
     "properties": {
         "image": {"type": "string"},
@@ -42,7 +42,7 @@ docker_compose_device_schema = {
                 "required": ["name", "value"],
                 "properties": {
                     "name": {"type": "string"},
-                    "value": {"type": ["string", "number"]},
+                    "value": {"type": ["string", "number", "boolean"]},
                 },
             },
         },
